;===============================================================================================================================================================================================
; load relevant extensions =====================================================================================================================================================================
; ==============================================================================================================================================================================================
extensions[nw]

;===============================================================================================================================================================================================
; create global and other variables ============================================================================================================================================================
; ==============================================================================================================================================================================================
globals
[
  actor_i            ; for each dyadic interaction, indicates which actor has been selected first
  actor_j            ; for each dyadic interaction, indicates which actor has been selected second
  actors             ; auxiliary agent set that consists of the two actors
  supported_belief   ; belief that has been supported by the current interaction

  LS                 ; LS measure
  NBS                ; NBS measure
  N1_1               ; auxiliary variable for calculating NBS, counts the pairs of actors who share a tie and hold the same state on S
  N1_2               ; auxiliary variable for calculating NBS, counts the pairs of actors who do not share a tie and hold the same state on S
  N2_1               ; auxiliary variable for calculating NBS, counts the pairs of actors who share a tie and do not hold the same state on S
  N2_2               ; auxiliary variable for calculating NBS, counts the pairs of actors who do not share a tie and do not hold the same state on S
  actors_A           ; auxiliary variable that counts the number of actors that believe A
  actors_O           ; auxiliary variable that counts the number of actors that do not believe anything
  actors_B           ; auxiliary variable that counts the number of actors that believe B

  num_components     ; auxiliary variable that counts the components during the network generation process
  my-seed            ; auxiliary variable that makes it possible to employ a user-generated seed

  network_clustering           ; stores the measure of network clustering
  network_path_length          ; stores the measure of the average shortest path length
  component_adjustments_needed ; auxiliary variable that indicates how many network components needed to be merged
  diff_cat_adjustments_needed  ; auxiliary variable that indicates how many actors needed to be rewired to connect to a member of a different category
]

turtles-own
[
  N      ; nominal distinction
  S      ; status belief
  M1     ; actor's memory: auxiliary list that contains the indexes of all those other actors with whom the actor has already interacted
  M2     ; actor's memory: auxiliary list that contains the experiences during the last interactions with all those other actors with whom the actor has already interacted
  M3     ; actor's memory: auxiliary list that contains information as to whether a given experience is stable

  paired ; auxiliary variable that is needed when calculating NBS

  fix_A                   ; auxiliary variable that indicates how many of the actor's experiences that support the belief A are stable
  fix_B                   ; auxiliary variable that indicates how many of the actor's experiences that support the belief B are stable
  flex                    ; auxiliary variable that indicates how many of the actor's experiences are flexible
  individually_converged  ; indicates whether the actor is in an individually stable state

  component_member        ; auxiliary variable that helps ensuring that there is only one component
  temp_prob               ; auxiliary variable that is needed in the network generation process
]

; ============================================================================================================================================================================================
; initialize model run =======================================================================================================================================================================
; ============================================================================================================================================================================================
to setup
  __clear-all-and-reset-ticks
  do_make_seed
  do_make_world
  do_make_actors
  if interaction_regime = "network" [do_make_network]
  do_initialize_memories
end

to do_make_seed
  if seed_to_use = "random"
  [
    set my-seed new-seed                         ; generate a new seed
    output-print word "Seed used: " my-seed      ; print it out
    random-seed my-seed                          ; use the new seed
  ]

  if seed_to_use = "user_defined"
  [
    set my-seed user_defined_seed                ; get your own seed from text field
    output-print word "Seed used: " my-seed      ; print it out again
    random-seed my-seed                          ; use the seed
  ]
end

to do_make_world
  resize-world 0 W - 1 0 W - 1
  ask patches [set pcolor 9.9]
end

to do_make_actors
  create-turtles I / 2 [set N "A" set S "O"] ; make 50% of the actors belong to category A, no actor holds a status belief
  create-turtles I / 2 [set N "B" set S "O"] ; make 50% of the actors belong to category B, no actor holds a status belief

  ; randomly distribute actors across the world and assign them colors/shapes
  ask turtles
    [
      if N = "A" [set shape "triangle"]
      if N = "B" [set shape "circle"]
      if S = "A" [set color 15]
      if S = "O" [set color 9.9]
      if S = "B" [set color 65]
      set M1[]
      set M2[]
      set M3[]
      set size 0.1
      setxy random-xcor random-ycor
    ]
end

to do_make_network
 set component_adjustments_needed 0
 set diff_cat_adjustments_needed 0

 ask turtles
  [
    let ego who      ; auxiliary variable that indicates the focal actor
    let tie_count 0  ; auxiliary variable that tracks how many ties the actor has already established

    while [tie_count < k]
    [
      ; if the actor has not yet established k ties yet, determine who is still available for creating a tie and then
      ; loop through the alternatives and select one of them with a probability that is proportional to the spatial
      ; distance to the focal actor
      let set_potential_interactors turtles with [(link-neighbor? turtle ego = FALSE) and (who != [who] of turtle ego)]
      if count set_potential_interactors > 0
      [
        ask set_potential_interactors [set temp_prob exp( - 1 * y *  distance turtle ego)]
        let alter nobody
        let pick random-float (sum [temp_prob] of set_potential_interactors)
        let comp_low 0
        let comp_high 0
        ask set_potential_interactors
        [
          if alter = nobody
          [
            set comp_high comp_high + temp_prob
            ifelse pick >= comp_low and pick < comp_high
            [
              set alter who
            ]
            [
              set comp_low comp_high
            ]
          ]
        ]
        ask turtle alter [create-link-with turtle ego]
        set tie_count tie_count + 1
      ]
    ]
  ]

  ; after all ties have been established check for each actor whether he/she has at least one interaction partner
  ; who belongs to a different category; if the actor has no such link neighbor yet, rewire one tie that he/she
  ; maintains with somebody who belongs to the same category
  ask turtles
  [
    let ego who
    let temp_oppo_contacts count turtles with [(link-neighbor? turtle ego = TRUE) and (N != [N] of turtle ego)]
    while [temp_oppo_contacts = 0]
    [
      set diff_cat_adjustments_needed diff_cat_adjustments_needed + 1
      ask one-of links with [[N] of end1 = [N] of end2 and ([who] of end1 = ego or [who] of end2 = ego)] [die]
      create-link-with one-of turtles with [N != [N] of turtle ego]
      set temp_oppo_contacts count turtles with [(link-neighbor? turtle ego = TRUE) and (N != [N] of turtle ego)]
    ]
  ]

  ; check whether the resulting network has only one component; if necessary, rewire one tie and check again
  if require_giant_component = true [do_check_network_components]

  ; format the links
  ask links [set color 7]

  ; calculate network measures
  set network_clustering (mean [nw:clustering-coefficient] of turtles)
  set network_path_length (nw:mean-path-length)

end

to do_check_network_components
  set num_components 0                 ; a the start, there is no component
  ask turtles [set component_member 0] ; a the start, no actor belongs to any component

  ; start by selecting one turtle at random and assign him/her to the first component; then loop through all his/her
  ; link neighbors and their link neighbors and so on and assign them to the same component; then select another actor
  ; at random who has not been assigned to a component yet and do the same; repeat until all actors have been assigned to
  ; a component; the information to which component the actors belong is then used to connect two members of different
  ; components, if there is more than one component; this process is repeated until there is only one component left
  ask turtles
  [
    if component_member = 0 [set num_components num_components + 1]
    do_set_component_member
  ]

  if max [component_member] of turtles > 1
  [
    set component_adjustments_needed component_adjustments_needed + 1

    let a1 one-of turtles with [component_member = 1]
    let a2 one-of turtles with [component_member > 1 and N != [N] of a1]

    ask a1
    [
      ask one-of links with [[N] of end1 = [N] of end2][die]
      create-link-with a2
    ]

    do_check_network_components
  ]
end

to do_set_component_member
  if component_member > 0 [stop]
  set component_member num_components
  ask link-neighbors [do_set_component_member]
end

to do_initialize_memories
  ask turtles
  [
    ; if actors consider multiple experiences, the three memory lists are initialized in one of two ways;
    ; if there is a network, the length of each list is set equal to the number of actors to which a given actor is
    ; connected and from whom he/she differs in N; if there is no network, the memory length is set equal to the number
    ; of all actors who differ from the focal actor in N; if actors do not consider multiple experiences, only M2 is considered
    ; and the length of this lists is set to 1
    ifelse (inertia_possible = "yes")
    [
      let ego who

      ifelse (interaction_regime = "network")
      [
       set M1 [who] of link-neighbors with [N != [N] of turtle ego]
      ]
      [
       set M1 [who] of turtles with [N != [N] of turtle ego]
      ]
      set M2 M1
      set M3 M1

      foreach M1 [x -> let test position x M1 set M2 replace-item test M2 "NA"]
      foreach M1 [x -> let test position x M1 set M3 replace-item test M3 "flex"]
    ]
    [
      set M2 ["NA"]
    ]
  ]
end

; ================================================================================================================================================================================================
; simulation process =============================================================================================================================================================================
; ================================================================================================================================================================================================
to go
  do_select_interactants
  do_interaction
  do_memory_update
  do_belief_update
  tick

  if check_convergence = TRUE
  [
    if ticks mod interval_check_convergence = 0
    [
      do_check_convergence
      if stop_when_converged = true
      [
        if count turtles with [individually_converged = 1] = count turtles
        [
          if calculate_outcomes = TRUE
          [
            do_calculate_outcome_measures
          ]
          stop
        ]
      ]
    ]
  ]
end

to do_select_interactants
  set actor_i one-of turtles
  ask actor_i
  [
    ifelse (interaction_regime = "network")
    [
      set actor_j one-of turtles with [(link-neighbor? actor_i = TRUE) and (N != [N] of actor_i)]
    ]
    [
      set actor_j one-of turtles with [(N != [N] of actor_i)]
    ]
  ]
  set actors turtles with [(who = [who] of actor_i) or (who = [who] of actor_j)]
end

to do_interaction
  ; given the actors' states on N and S, determine whether a hierarchy emerges and what state on S this hierarchy supports
  set supported_belief "O"
  ifelse [S] of actor_i = "O"
  [
    if [S] of actor_j = "A" [set supported_belief "A"]
    if [S] of actor_j = "B" [set supported_belief "B"]
    if [S] of actor_j = "O" and random-float (1) < h [ifelse random 2 = 0 [set supported_belief "A"][set supported_belief "B"]]
  ]
  [
    ifelse [S] of actor_i = "A"
    [
      if [S] of actor_j = "A" [set supported_belief "A"]
      if [S] of actor_j = "B" and random-float (1) < h [ifelse random 2 = 0 [set supported_belief "A"][set supported_belief "B"]]
      if [S] of actor_j = "O" [set supported_belief "A"]
    ]
    [
      if [S] of actor_j = "A" and random-float (1) < h [ifelse random 2 = 0 [set supported_belief "A"][set supported_belief "B"]]
      if [S] of actor_j = "B" [set supported_belief "B"]
      if [S] of actor_j = "O" [set supported_belief "B"]
    ]
  ]
end

to do_memory_update
  ask actors
  [
    ; update the element in the actors' memories that corresponds to the their interaction partner with the result of their most
    ; recent interaction; if actors only consider one experience, update this with the outcome of the interaction
    ifelse (inertia_possible = "yes")
    [
      let ego who
      let alter [who] of one-of actors with [who != [who] of turtle ego]
      let temp_indicator position [who] of turtle alter  M1
      set M2 replace-item temp_indicator M2 supported_belief
    ]
    [
      set M2 supported_belief
    ]
  ]
end

to do_belief_update
  ask actors
  [
    ; if actors consider multiple experiences, check which belief is supported how strongly and determine whether this
    ; is sufficient for belief acquisition or maintenance
    ifelse (inertia_possible = "yes")
    [
      let support_A filter [?1 -> first ?1 = "A"] M2
      let support_O filter [?1 -> first ?1 = "O"] M2
      let support_B filter [?1 -> first ?1 = "B"] M2

      let temp_consensual "O"

      if ((length support_A) / (length support_A + length support_O + length support_B) > consensus_needed)
      [
        set temp_consensual "A"
      ]

      if ((length support_B) / (length support_A + length support_O + length support_B) > consensus_needed)
      [
        set temp_consensual "B"
      ]

      if S = "O" and temp_consensual != "O"
      [
        if random-float (1) < a [set S temp_consensual]
      ]
      if S != "O" and temp_consensual != S
      [
        if random-float (1) < l [set S "O"]
      ]
    ]
    [
      if S = "O" and M2 != "O"
      [
        if random-float (1) < a [set S M2]
      ]
      if S != "O" and M2 != S
      [
        if random-float (1) < l [set S "O"]
      ]
    ]

    if S = "A" [set color 15]
    if S = "O" [set color 9.9]
    if S = "B" [set color 65]
  ]
end

to do_check_convergence
  ifelse inertia_possible = "yes"
  [
    ; check for each actor whether he/she is in an individually stable configuration; if all actors are in such a configuration,
    ; the simulation run can be stopped
    ask turtles
    [
      set individually_converged 0
      let ego who
      set fix_A 0
      set fix_B 0
      set flex 0

      foreach M1
      [ ?1 ->
        let alter_indicator ?1
        let memory_item_indicator position alter_indicator M1

        ifelse (S != "O")
        [
          ifelse (item memory_item_indicator M2 = S) and (item memory_item_indicator M2 = [S] of turtle alter_indicator or [S] of turtle alter_indicator = "O")
          [
            set M3 replace-item memory_item_indicator M3 "fix"

            if item memory_item_indicator M2 = "A" [set fix_A fix_A + 1]
            if item memory_item_indicator M2 = "B" [set fix_B fix_B + 1]
          ]
          [
            set M3 replace-item memory_item_indicator M3 "flex"
          ]
        ]
        [
          ifelse (item memory_item_indicator M2 = [S] of turtle alter_indicator)
          [
            set M3 replace-item memory_item_indicator M3 "fix"

            if item memory_item_indicator M2 = "A" [set fix_A fix_A + 1]
            if item memory_item_indicator M2 = "B" [set fix_B fix_B + 1]
          ]
          [
            set M3 replace-item memory_item_indicator M3 "flex"
          ]
        ]
      ]

      if S = "A" and ((fix_A / length M1) > consensus_needed) [set individually_converged 1]
      if S = "B" and ((fix_B / length M1) > consensus_needed) [set individually_converged 1]
      if S = "O" and ((length M1 - fix_A) / length M1 <= consensus_needed) and ((length M1 - fix_B) / length M1 <= consensus_needed) [set individually_converged 1]
    ]
  ]
  [
    if (count turtles with [S = "A"] = count turtles) or (count turtles with [S = "B"] = count turtles)
    [
      ask turtles
      [
        set individually_converged 1
      ]
    ]
  ]

  ; if requested, actors who are in an individually stable state are marked with an x
  if (mark_stable = true)
  [
    ask turtles
    [
      ifelse (individually_converged = 1)
      [
        set shape "x"
      ]
      [
        if N = "A" [set shape "triangle"]
        if N = "B" [set shape "circle"]
      ]
    ]
  ]
end

to do_calculate_outcome_measures
  ; calculate LS
  ifelse count turtles with [S =  "A"] > count turtles with [S =  "B"][set LS count turtles with [S =  "A"] / count turtles][set LS count turtles with [S =  "B"] / count turtles]

  ;calculate NBS
  if (interaction_regime = "network")
  [
    set N1_1 0
    set N1_2 0
    set N2_1 0
    set N2_2 0

    ask turtles [set paired 0]

    ask turtles
    [
      let ego who
      set paired 1
      ask turtles with [paired != 1]
      [
        let alter who
        ifelse link-neighbor? turtle ego = TRUE
        [
          ifelse [S] of turtle ego = [S] of turtle alter [set N1_1 N1_1 + 1][set N2_1 N2_1 + 1]
        ]
        [
          ifelse [S] of turtle ego = [S] of turtle alter [set N1_2 N1_2 + 1][set N2_2 N2_2 + 1]
        ]
      ]
    ]
    set NBS ln((N1_1 / (N1_1 + N2_1)) / (N1_2 / (N1_2 + N2_2)))
  ]

  ; count actors with the different states on S
  set actors_A count turtles with [S = "A"]
  set actors_O count turtles with [S = "O"]
  set actors_B count turtles with [S = "B"]
end
@#$#@#$#@
GRAPHICS-WINDOW
808
13
1316
522
-1
-1
100.0
1
10
1
1
1
0
0
0
1
0
4
0
4
0
0
1
ticks
30.0

BUTTON
17
18
80
51
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
92
18
160
51
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
18
242
191
275
h
h
0.01
1
0.5
0.01
1
NIL
HORIZONTAL

SLIDER
18
283
191
316
a
a
0.01
1
0.5
0.01
1
NIL
HORIZONTAL

SLIDER
18
322
191
355
l
l
0.01
1
0.5
0.01
1
NIL
HORIZONTAL

OUTPUT
390
214
565
269
11

CHOOSER
387
88
564
133
seed_to_use
seed_to_use
"random" "user_defined"
0

INPUTBOX
389
141
565
201
user_defined_seed
5.422331708753569E15
1
0
Number

SWITCH
391
327
564
360
check_convergence
check_convergence
0
1
-1000

TEXTBOX
1328
13
1478
31
Outcomes
11
0.0
1

SLIDER
19
87
191
120
I
I
2
1000
500.0
2
1
NIL
HORIZONTAL

SLIDER
19
126
190
159
W
W
1
10
5.0
1
1
NIL
HORIZONTAL

TEXTBOX
389
66
539
84
Auxiliary parameters
11
0.0
1

SWITCH
390
278
563
311
require_giant_component
require_giant_component
0
1
-1000

INPUTBOX
107
167
190
227
y
8.0
1
0
Number

INPUTBOX
19
167
99
227
k
5.0
1
0
Number

TEXTBOX
22
66
210
89
Main parameters
11
0.0
1

MONITOR
1328
33
1426
78
LS
LS
3
1
11

MONITOR
1328
83
1426
128
NBS
NBS
6
1
11

SWITCH
389
552
561
585
calculate_outcomes
calculate_outcomes
0
1
-1000

INPUTBOX
389
488
561
548
interval_check_convergence
20000.0
1
0
Number

SWITCH
389
443
562
476
stop_when_converged
stop_when_converged
0
1
-1000

MONITOR
1328
134
1425
179
converged
count turtles with [individually_converged = 1] = count turtles
0
1
11

CHOOSER
18
361
191
406
interaction_regime
interaction_regime
"random" "network"
1

CHOOSER
18
411
191
456
inertia_possible
inertia_possible
"yes" "no"
0

SWITCH
391
366
565
399
mark_stable
mark_stable
1
1
-1000

CHOOSER
18
463
191
508
consensus_needed
consensus_needed
0.5 0.7 0.9
0

TEXTBOX
198
361
375
417
Should networks be considered, or should interactions occur completely at random?
11
0.0
1

TEXTBOX
199
409
369
451
Should belief inertia be possible?
11
0.0
1

TEXTBOX
199
463
368
519
If belief inertia is possible, what is the threshold for belief acquisition/maintenance?
11
0.0
1

TEXTBOX
579
88
754
130
Should a random or a user-defined seed be used? This makes it possible to reproduce runs.
11
0.0
1

TEXTBOX
577
143
751
161
Value of the use-defined seed
11
0.0
1

TEXTBOX
577
214
756
242
Value of seed that was actually used.
11
0.0
1

TEXTBOX
576
275
753
317
Should only networks be considered that consist of only one component? If not, beliefs might not diffuse.
11
0.0
1

TEXTBOX
575
324
754
352
Should model convergence be assessed?
11
0.0
1

TEXTBOX
576
365
755
435
If convergence is assessed, should actors who are in an individually stable configuration be marked? This makes it easier to assess the model's behavior.
11
0.0
1

TEXTBOX
575
443
757
485
If convergence is assessed, should the run be stopped when it has converged?
11
0.0
1

TEXTBOX
573
490
755
546
How many interactions should occur before convergence is assessed (again)? Choosing large values helps speed up the simulation.
11
0.0
1

TEXTBOX
572
550
751
592
Should the outcome measures be calculated when the model has converged and stops?
11
0.0
1

MONITOR
808
553
926
598
NIL
network_clustering
3
1
11

MONITOR
939
553
1071
598
network_path_length
network_path_length
3
1
11

TEXTBOX
811
532
961
550
Network properties
11
0.0
1

MONITOR
1083
553
1280
598
component_adjustments_needed
component_adjustments_needed
1
1
11

MONITOR
1285
553
1464
598
diff_cat_adjustments_needed
diff_cat_adjustments_needed
1
1
11

@#$#@#$#@
## WHAT IS IT?

This section could give a general understanding of what the model is trying to show or explain.

## HOW IT WORKS

This section could explain what rules the agents use to create the overall behavior of the model.

## HOW TO USE IT

This section could explain how to use the model, including a description of each of the items in the interface tab.

## THINGS TO NOTICE

This section could give some ideas of things for the user to notice while running the model.

## THINGS TO TRY

This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.

## EXTENDING THE MODEL

This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.

## NETLOGO FEATURES

This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.

## RELATED MODELS

This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.

## CREDITS AND REFERENCES

This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 false false 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

clock
true
0
Circle -7500403 true true 30 30 240
Polygon -16777216 true false 150 31 128 75 143 75 143 150 158 150 158 75 173 75
Circle -16777216 true false 135 135 30

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

spin
true
0

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 false false 150 30 285 255 15 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="no_network" repetitions="50" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100000000"/>
    <metric>LS</metric>
    <metric>NBS</metric>
    <metric>actors_A</metric>
    <metric>actors_O</metric>
    <metric>actors_B</metric>
    <metric>my-seed</metric>
    <metric>network_clustering</metric>
    <metric>network_path_length</metric>
    <metric>diff_cat_adjustments_needed</metric>
    <metric>component_adjustments_needed</metric>
    <enumeratedValueSet variable="interaction_regime">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="belief_regime">
      <value value="&quot;single&quot;"/>
      <value value="&quot;multiple&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="h">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consensus_needed">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="check_convergence">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed">
      <value value="5422331708753569"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="calculate_outcomes">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interval_check_convergence">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="require_giant_component">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="W">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark_stable">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop_when_converged">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="I">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="network" repetitions="50" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100000000"/>
    <metric>LS</metric>
    <metric>NBS</metric>
    <metric>actors_A</metric>
    <metric>actors_O</metric>
    <metric>actors_B</metric>
    <metric>my-seed</metric>
    <metric>network_clustering</metric>
    <metric>network_path_length</metric>
    <metric>diff_cat_adjustments_needed</metric>
    <metric>component_adjustments_needed</metric>
    <enumeratedValueSet variable="interaction_regime">
      <value value="&quot;network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="belief_regime">
      <value value="&quot;single&quot;"/>
      <value value="&quot;multiple&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="h">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consensus_needed">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="0"/>
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="check_convergence">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed">
      <value value="5422331708753569"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="calculate_outcomes">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interval_check_convergence">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="require_giant_component">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="W">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark_stable">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop_when_converged">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="I">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="network_sensitivity" repetitions="50" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100000000"/>
    <metric>LS</metric>
    <metric>NBS</metric>
    <metric>actors_A</metric>
    <metric>actors_O</metric>
    <metric>actors_B</metric>
    <metric>my-seed</metric>
    <metric>network_clustering</metric>
    <metric>network_path_length</metric>
    <metric>diff_cat_adjustments_needed</metric>
    <metric>component_adjustments_needed</metric>
    <enumeratedValueSet variable="interaction_regime">
      <value value="&quot;network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="belief_regime">
      <value value="&quot;multiple&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="h">
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consensus_needed">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="check_convergence">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed">
      <value value="5422331708753569"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="calculate_outcomes">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interval_check_convergence">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="require_giant_component">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="W">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark_stable">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop_when_converged">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="I">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="consensus_sensitivity" repetitions="50" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100000000"/>
    <metric>LS</metric>
    <metric>NBS</metric>
    <metric>actors_A</metric>
    <metric>actors_O</metric>
    <metric>actors_B</metric>
    <metric>my-seed</metric>
    <metric>network_clustering</metric>
    <metric>network_path_length</metric>
    <metric>diff_cat_adjustments_needed</metric>
    <metric>component_adjustments_needed</metric>
    <enumeratedValueSet variable="interaction_regime">
      <value value="&quot;network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="belief_regime">
      <value value="&quot;multiple&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consensus_needed">
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="h">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="check_convergence">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed">
      <value value="5422331708753569"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="calculate_outcomes">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interval_check_convergence">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="require_giant_component">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="W">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark_stable">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop_when_converged">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="I">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="cv_test" repetitions="120" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100000000"/>
    <metric>LS</metric>
    <metric>NBS</metric>
    <metric>actors_A</metric>
    <metric>actors_O</metric>
    <metric>actors_B</metric>
    <metric>my-seed</metric>
    <metric>network_clustering</metric>
    <metric>network_path_length</metric>
    <metric>diff_cat_adjustments_needed</metric>
    <metric>component_adjustments_needed</metric>
    <enumeratedValueSet variable="interaction_regime">
      <value value="&quot;network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="belief_regime">
      <value value="&quot;multiple&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="h">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consensus_needed">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="check_convergence">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed">
      <value value="5422331708753569"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="calculate_outcomes">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interval_check_convergence">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="require_giant_component">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="W">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark_stable">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop_when_converged">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="I">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Polygon -16777216 true false 150 150 157 156 143 156

dash
0.0
-0.2 0 0.0 1.0
0.0 1 2.0 2.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
